.. -*- coding: utf-8 -*-

.. _adk-equilibrium:

==========================
 AdK equilibrium dataset
==========================

.. module:: MDAnalysisData.adk_equilibrium

The :mod:`MDAnalysisData.adk_equilibrium` module contains a 1-µs
equilibrium MD trajectory of a globular protein with all solvent
removed. It can be used to study protein dynamics.

.. currentmodule:: MDAnalysisData.adk_equilibrium

.. autosummary::

   fetch_adk_equilibrium


.. include:: ../MDAnalysisData/descr/adk_equilibrium.rst

.. autofunction:: fetch_adk_equilibrium

		  
